@@ -1,8 +1,6 @@
 package Module::Starter::Plugin::Template;
 # vi:et:sw=4 ts=4
 
-our $VERSION = '0.01';
-
 use warnings;
 use strict;
 
@@ -10,6 +8,16 @@ use strict;
 
 Module::Starter::Plugin::Template - module starter with templates
 
+=head1 VERSION
+
+Version 0.02
+
+    $Id: /my/petdance/ms/trunk/lib/Module/Starter/Plugin/Template.pm 2677 2005-08-20T04:00:44.121762Z andy  $
+
+=cut
+
+our $VERSION = '0.02';
+
 =head1 SYNOPSIS
 
  use Module::Starter qw(
@@ -89,14 +97,14 @@ sub render {
 All of the C<FILE_guts> methods from Module::Starter::Simple are subclassed to
 look something like this:
 
- sub file_guts {
-   my $self = shift;
-   my %options;
-   @options{qw(first second third)} = @_;
+    sub file_guts {
+        my $self = shift;
+        my %options;
+        @options{qw(first second third)} = @_;
 
-   my $template = $self->{templates}{filename};
-   $self->render($template, \%options);
- }
+        my $template = $self->{templates}{filename};
+        $self->render($template, \%options);
+    }
 
 These methods will need to be rewritten when (as is likely)
 Module::Starter::Simple's _guts methods are refactored into a registry.
@@ -213,18 +221,18 @@ sub cvsignore_guts {
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES, C<< <rjbs at cpan.org> >>
 
 =head1 Bugs
 
 Please report any bugs or feature requests to
-C<bug-module-starter@rt.cpan.org>, or through the web interface at
+C<bug-module-starter at rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
 notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT
 
-Copyright 2004 Ricardo SIGNES, All Rights Reserved.
+Copyright 2005 Ricardo SIGNES, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
