@@ -12,13 +12,11 @@ Module::Starter::Simple - a simple, comprehensive Module::Starter plugin
 
 =head1 VERSION
 
-Version 1.22
-
-    $Header: /home/cvs/module-starter/lib/Module/Starter/Simple.pm,v 1.4 2004/07/21 22:50:32 rjbs Exp $
+Version 1.41_01
 
 =cut
 
-our $VERSION = '1.22';
+our $VERSION = '1.41_01';
 
 =head1 SYNOPSIS
 
@@ -49,9 +47,15 @@ sub create_distro {
     my $modules = $self->{modules} || [];
     my @modules = map { split /,/ } @$modules;
     die "No modules specified.\n" unless @modules;
+    for (@modules) {
+        die "Invalid module name: $_" unless /\A[a-z_]\w*(?:::[\w]+)*\Z/i;
+    }
 
     die "Must specify an author\n" unless $self->{author};
     die "Must specify an email address\n" unless $self->{email};
+    ($self->{email_obfuscated} = $self->{email}) =~ s/@/ at /;
+
+    $self->{license} ||= 'perl';
 
     if ( not defined $self->{distro} ) {
         $self->{distro} = $modules[0];
@@ -67,11 +71,18 @@ sub create_distro {
     push @files, $self->create_t( @modules );
     push @files, $self->create_cvsignore;
 
-    my @builders = (ref $self->{builder} eq "ARRAY") ?  @{$self->{builder}} : ($self->{builder});
+    my @builders;
+    if (ref $self->{builder} eq "ARRAY") {
+        my %unique = map { $_ => 1 } @{$self->{builder}};
+        @builders = keys %unique;
+    } else {
+        @builders = ($self->{builder});
+    }
 
     # this block should be pulled out to its own sub
     my @build_instructions;
     for my $builder ( @builders ) {
+        next unless $builder;
         if ( !@build_instructions ) {
             push @build_instructions, "To install this module, run the following commands:";
         } else {
@@ -185,12 +196,31 @@ method eventually.)
 
 =cut
 
+sub _license_blurb {
+  my $self = shift;
+  my $license_blurb;
+
+  if ($self->{license} eq 'perl') {
+    $license_blurb = <<EOT;
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+EOT
+  } else {
+    $license_blurb = <<EOT;
+This program is released under the following license: $self->{license}
+EOT
+  }
+  chomp $license_blurb;
+  return $license_blurb;
+}
+
 sub module_guts {
     my $self = shift;
     my $module = shift;
     my $rtname = shift;
 
     my $year = $self->_thisyear();
+    my $license_blurb = $self->_license_blurb();
 
     my $content = <<"HERE";
 package $module;
@@ -202,7 +232,7 @@ use strict;
 
 $module - The great new $module!
 
-\=head1 Version
+\=head1 VERSION
 
 Version 0.01
 
@@ -210,7 +240,7 @@ Version 0.01
 
 our \$VERSION = '0.01';
 
-\=head1 Synopsis
+\=head1 SYNOPSIS
 
 Quick summary of what the module does.
 
@@ -221,12 +251,12 @@ Perhaps a little code snippet.
     my \$foo = $module->new();
     ...
 
-\=head1 Export
+\=head1 EXPORT
 
 A list of functions that can be exported.  You can delete this section
 if you don't export anything, such as for a purely object-oriented module.
 
-\=head1 Functions
+\=head1 FUNCTIONS
 
 \=head2 function1
 
@@ -242,29 +272,30 @@ sub function1 {
 sub function2 {
 }
 
-\=head1 Author
+\=head1 AUTHOR
 
-$self->{author}, C<< <$self->{email}> >>
+$self->{author}, C<< <$self->{email_obfuscated}> >>
 
-\=head1 Bugs
+\=head1 BUGS
 
 Please report any bugs or feature requests to
 C<bug-$rtname\@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically
-be notified of progress on your bug as I make changes.
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=$self->{distro}>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
-\=head1 Copyright & License
+\=head1 ACKNOWLEDGEMENTS
 
-Copyright $year $self->{author}, All Rights Reserved.
+\=head1 COPYRIGHT & LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+Copyright $year $self->{author}, all rights reserved.
+
+$license_blurb
 
 \=cut
 
 1; # End of $module
 HERE
-    $content =~ s/^\\=/=/smg;
     return $content;
 }
 
@@ -290,6 +321,9 @@ sub _create_module {
 
     my $module_file = File::Spec->catfile( @dirparts,  $filepart );
 
+    $self->{module_file}{$module} =
+        File::Spec->catfile('lib', @parts, $filepart);
+
     open( my $fh, ">", $module_file ) or die "Can't create $module_file: $!\n";
     print $fh $self->module_guts( $module, $rtname );
     close $fh;
@@ -315,6 +349,7 @@ sub create_Makefile_PL {
     my @parts = split( /::/, $main_module );
     my $pm = pop @parts;
     my $main_pm_file = File::Spec->catfile( "lib", @parts, "${pm}.pm" );
+       $main_pm_file =~ s{\\}{/}g; # even on Win32, use forward slash
 
     my $fname = File::Spec->catfile( $self->{basedir}, "Makefile.PL" );
     open( my $fh, ">", $fname ) or die "Can't create $fname: $!\n";
@@ -340,6 +375,8 @@ sub Makefile_PL_guts {
     my $main_module = shift;
     my $main_pm_file = shift;
 
+    (my $author = "$self->{author} <$self->{email}>") =~ s/'/\'/g;
+
     return <<"HERE";
 use strict;
 use warnings;
@@ -347,7 +384,7 @@ use ExtUtils::MakeMaker;
 
 WriteMakefile(
     NAME                => '$main_module',
-    AUTHOR              => '$self->{author} <$self->{email}>',
+    AUTHOR              => '$author',
     VERSION_FROM        => '$main_pm_file',
     ABSTRACT_FROM       => '$main_pm_file',
     PL_FILES            => {},
@@ -375,6 +412,7 @@ sub create_Build_PL {
     my @parts = split( /::/, $main_module );
     my $pm = pop @parts;
     my $main_pm_file = File::Spec->catfile( "lib", @parts, "${pm}.pm" );
+       $main_pm_file =~ s{\\}{/}g; # even on Win32, use forward slash
 
     my $fname = File::Spec->catfile( $self->{basedir}, "Build.PL" );
     open( my $fh, ">", $fname ) or die "Can't create $fname: $!\n";
@@ -400,6 +438,8 @@ sub Build_PL_guts {
     my $main_module = shift;
     my $main_pm_file = shift;
 
+    (my $author = "$self->{author} <$self->{email}>") =~ s/'/\'/g;
+
     return <<"HERE";
 use strict;
 use warnings;
@@ -408,9 +448,9 @@ use Module::Build;
 my \$builder = Module::Build->new(
     module_name         => '$main_module',
     license             => '$self->{license}',
-    dist_author         => '$self->{author} <$self->{email}>',
+    dist_author         => '$author',
     dist_version_from   => '$main_pm_file',
-    requires => {
+    build_requires => {
         'Test::More' => 0,
     },
     add_to_cleanup      => [ '$self->{distro}-*' ],
@@ -491,6 +531,7 @@ sub README_guts {
     my $build_instructions = shift;
 
     my $year = $self->_thisyear();
+    my $license_blurb = $self->_license_blurb();
 
 return <<"HERE";
 $self->{distro}
@@ -512,12 +553,9 @@ $build_instructions
 
 COPYRIGHT AND LICENCE
 
-Put the correct copyright and licence information here.
-
 Copyright (C) $year $self->{author}
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+$license_blurb
 HERE
 }
 
@@ -575,18 +613,74 @@ HERE
 
     my $nmodules = @modules;
     my $main_module = $modules[0];
-    my $use_lines = join( "\n", map { "use_ok( '$_' );" } @modules );
+    my $use_lines = join( "\n", map { "\tuse_ok( '$_' );" } @modules );
+
+    $t_files{'00-load.t'} = <<"HERE";
+#!perl -T
 
-    $t_files{'00.load.t'} = <<"HERE";
 use Test::More tests => $nmodules;
 
 BEGIN {
 $use_lines
 }
 
-diag( "Testing $main_module \$${main_module}::VERSION" );
+diag( "Testing $main_module \$${main_module}::VERSION, Perl \$], \$^X" );
 HERE
 
+    my $boilerplate_tests = @modules + 2 + $[;
+    $t_files{'boilerplate.t'} = <<"HERE";
+#!perl -T
+
+use strict;
+use warnings;
+use Test::More tests => $boilerplate_tests;
+
+sub not_in_file_ok {
+    my (\$filename, \%regex) = \@_;
+    open my \$fh, "<", \$filename
+        or die "couldn't open \$filename for reading: \$!";
+    
+    my \%violated;
+    
+    while (my \$line = <\$fh>) {
+        while (my (\$desc, \$regex) = each \%regex) {
+            if (\$line =~ \$regex) {
+                push \@{\$violated{\$desc}||=[]}, \$.;
+            }
+        }
+    }
+
+    if (\%violated) {
+        fail("\$filename contains boilerplate text");
+        diag "\$_ appears on lines \@{\$violated{\$_}}" for keys \%violated;
+    } else {
+        pass("\$filename contains no boilerplate text");
+    }
+}
+
+not_in_file_ok(README =>
+    "The README is used..."       => qr/The README is used/,
+    "'version information here'"  => qr/to provide version information/,
+);
+
+not_in_file_ok(Changes =>
+    "placeholder date/time"       => qr(Date/time)
+);
+
+sub module_boilerplate_ok {
+    my (\$module) = \@_;
+    not_in_file_ok(\$module =>
+        'the great new \$MODULENAME'   => qr/ - The great new /,
+        'boilerplate description'     => qr/Quick summary of what the module/,
+        'stub function definition'    => qr/function[12]/,
+    );
+}
+
+HERE
+
+    $t_files{'boilerplate.t'}
+        .= "module_boilerplate_ok('$self->{module_file}{$_}');\n" for @modules;
+
     return %t_files;
 }
 
@@ -664,6 +758,7 @@ sub create_cvsignore {
     open( my $fh, ">", $fname ) or die "Can't create $fname: $!\n";
     print $fh $self->cvsignore_guts();
     close $fh;
+    $self->progress( "Created $fname" );
 
     return; # Not a file that goes in the MANIFEST
 }
@@ -682,6 +777,8 @@ sub cvsignore_guts {
 blib*
 Makefile
 Makefile.old
+Build
+_build*
 pm_to_blib*
 *.tar.gz
 .lwpcookies
@@ -690,7 +787,7 @@ cover_db
 HERE
 }
 
-=head1 Helper Methods
+=head1 HELPER METHODS
 
 =head2 verbose
 
@@ -714,20 +811,20 @@ sub progress {
     return;
 }
 
-=head1 Bugs
+=head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-module-starter@rt.cpan.org>, or through the web interface at
+C<bug-module-starter at rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.  I will be notified, and then you'll automatically
 be notified of progress on your bug as I make changes.
 
-=head1 Author
+=head1 AUTHOR
 
 Andy Lester, C<< <andy@petdance.com> >>
 
 =head1 Copyright & License
 
-Copyright 2004 Andy Lester, All Rights Reserved.
+Copyright 2005 Andy Lester, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
